@@ -1,6 +1,6 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999 - 2014
+// Copyright Bob Friesenhahn, 1999 - 2015
 //
 // Definition of Image, the representation of a single image in Magick++
 //
@@ -115,7 +115,10 @@ namespace Magick
     // offset = constant to subtract from pixel neighborhood mean
     void            adaptiveThreshold ( const unsigned int width,
                                         const unsigned int height,
-                                        const unsigned offset = 0 );
+                                        const double offset = 0.0 );
+    void            adaptiveThreshold ( const unsigned int width,
+                                        const unsigned int height,
+                                        const unsigned int offset) MAGICK_FUNC_DEPRECATED;
 
     // Add noise to image with specified noise type
     void            addNoise ( const NoiseType noiseType_ );
@@ -591,6 +594,9 @@ namespace Magick
     void            reduceNoise ( void );
     void            reduceNoise ( const double order_ );
 
+    // Resets the image page canvas and position.
+    void            repage();
+
     // Resize image, specifying geometry, filter, and blur
     void            resize ( const Geometry &geometry_,
                              const FilterTypes filterType_,
@@ -777,7 +783,12 @@ namespace Magick
     void            animationIterations ( const unsigned int iterations_ );
     unsigned int    animationIterations ( void ) const;
 
-    // Access/Update a named image attribute
+    // Access/Update a named image text attribute.  Updates append the
+    // provided to any existing attribute text.  Pass NULL as the
+    // value to remove an existing value or before a subsequent call
+    // to add new text.
+    void            attribute ( const std::string name_,
+                                const char * value_ );
     void            attribute ( const std::string name_,
                                 const std::string value_ );
     std::string     attribute ( const std::string name_ );
@@ -907,6 +918,14 @@ namespace Magick
                                 const std::string &key_ ) const;
 
     // Vertical and horizontal resolution in pixels of the image
+    //
+    // The resolution is expressed in resolution units as supported by
+    // the resolutionUnits() method.
+    //
+    // Please note that the underlying resolution is floating point
+    // and use of this method will result in rounding floating point
+    // value to integer vaues.  Use the xResolution() and
+    // yResolution() methods when full accuracy is required.
     void            density ( const Geometry &geomery_ );
     Geometry        density ( void ) const;
 
@@ -1233,9 +1252,11 @@ namespace Magick
     std::string     x11Display ( void ) const;
 
     // x resolution of the image
+    void            xResolution ( const double x_resolution );
     double          xResolution ( void ) const;
 
     // y resolution of the image
+    void            yResolution ( const double y_resolution );
     double          yResolution ( void ) const;
 
     //////////////////////////////////////////////////////////////////////
